DynamicPolynomial

Struct DynamicPolynomial 

pub struct DynamicPolynomial<E> {
    pub coeffs: Vec<E>,
}
Polynomials of dynamic degree over an arbitrary semiring (fixed like Int, or dynamic like a random finite field). To be used in UAIR and PIOP where ZIP+ degree bound is not observed anymore.

This is a dumb data holder: all operations are performed via DynamicPolynomialConfig, obtainable from the coefficient config with HasDynamicPolynomialConfig::dyn_poly_cfg.

Note that operations involving dynamic polynomials do not trim leading zeros meaning one can end up with unequal objects of the type DynamicPolynomial<E> that represent equal polynomials, therefore DynamicPolynomialConfig::trim has to be called before checking equality.

Fields

coeffs: Vec<E>

Implementations

Source

impl<E> DynamicPolynomial<E>

pub const ZERO: Self

pub fn try_map<T, Er>( &self, f: impl FnMut(&E) -> Result<T, Er> + Copy, ) -> Result<DynamicPolynomial<T>, Er>

Maps every field element through f, preserving structure — used to lift elements into wire integers and to project wire integers back into elements at the (de)serialization boundary.

pub fn new(coeffs: impl AsRef<[E]>) -> Self
where E: Clone,

Create a new polynomial with the given coefficients.