pub struct DynamicPolynomial<E> {
pub coeffs: Vec<E>,
}Expand description
Polynomials of dynamic degree over an arbitrary semiring (fixed like
Int, or dynamic like a random finite field). To be used in UAIR and
PIOP where ZIP+ degree bound is not observed anymore.
This is a dumb data holder: all operations are performed via
DynamicPolynomialConfig, obtainable from the coefficient config with
HasDynamicPolynomialConfig::dyn_poly_cfg.
Note that operations involving dynamic polynomials
do not trim leading zeros meaning
one can end up with unequal objects of the type
DynamicPolynomial<E> that represent equal polynomials,
therefore DynamicPolynomialConfig::trim has to be called before
checking equality.
Fields
coeffs: Vec<E>Implementations
Sourceimpl<E> DynamicPolynomial<E>
impl<E> DynamicPolynomial<E>
pub const ZERO: Self